body{margin:0;padding:0;font-family:sans-serif}:root{--header-height:6vh}.app{width:100vw;height:100vh}.col{padding:10px;height:100%}.appHeader{background-color:#32325d;font-family:"Arial Black",Gadget,sans-serif;height:6vh;height:var(--header-height);color:#fff;font-size:3.5vh;box-shadow:0 4px 4px 0 rgba(0,0,0,.16),0 0 0 4px rgba(0,0,0,.08);line-height:6vh;line-height:var(--header-height)}.appContent{background-color:#fff;height:calc(100% - 6vh);height:calc(100% - var(--header-height))}.appLogo{height:3.5vh;padding:1px 5px}.shadowBox{box-shadow:0 2px 2px 0 rgba(0,0,0,.16),0 0 0 1px rgba(0,0,0,.08);margin:10px;display:block;position:absolute;top:0;left:0;right:0;bottom:0}.ant-tabs-content,.ant-tabs-tabpane{height:100%!important}::-webkit-scrollbar{width:0}::-webkit-scrollbar-thumb,::-webkit-scrollbar-track{background:#fff;opacity:0}::-webkit-scrollbar-thumb:hover{background:#fff;opacity:0}div.ViewTitle{padding:0 10px 2px;font-size:16px;color:#606e79;background:#f7f7f7}div.ViewBox{padding:3px 3px 5px;background:#fff}div#tooltip_proj{position:absolute;display:inline-block;padding:1px;font-family:"Open Sans",sans-serif;color:#000;background-color:#fff;border:1px solid #999;border-radius:2px;pointer-events:none;opacity:0;z-index:1}div.PanelBox{border:3px solid #f7f7f7}.AbsPos,div#tooltip{position:absolute}div#tooltip{display:inline-block;padding:1px;font-family:"Open Sans",sans-serif;color:#000;background-color:#fff;border:1px solid #999;border-radius:2px;pointer-events:none;opacity:0;z-index:1}.react-grid-layout{position:relative;transition:height .2s ease}.react-grid-item{transition:all .2s ease;transition-property:left,top}.react-grid-item.cssTransforms{transition-property:-webkit-transform;transition-property:transform;transition-property:transform,-webkit-transform}.react-grid-item.resizing{z-index:1;will-change:width,height}.react-grid-item.react-draggable-dragging{transition:none;z-index:3;will-change:transform}.react-grid-item.dropping{visibility:hidden}.react-grid-item.react-grid-placeholder{background:red;opacity:.2;transition-duration:.1s;z-index:2;-webkit-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.react-grid-item>.react-resizable-handle{position:absolute;width:20px;height:20px;bottom:0;right:0;cursor:se-resize}.react-grid-item>.react-resizable-handle:after{content:"";position:absolute;right:3px;bottom:3px;width:5px;height:5px;border-right:2px solid rgba(0,0,0,.4);border-bottom:2px solid rgba(0,0,0,.4)}.react-resizable{position:relative}.react-resizable-handle{position:absolute;width:20px;height:20px;background-repeat:no-repeat;background-origin:content-box;box-sizing:border-box;background-image:url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHN0eWxlPSJiYWNrZ3JvdW5kLWNvbG9yOiNmZmZmZmYwMCIgd2lkdGg9IjYiIGhlaWdodD0iNiI+PHBhdGggZD0iTTYgNkgwVjQuMmg0LjJWMEg2djZ6IiBvcGFjaXR5PSIuMzAyIi8+PC9zdmc+");background-position:100% 100%;padding:0 3px 3px 0}.react-resizable-handle-sw{bottom:0;left:0;cursor:sw-resize;-webkit-transform:rotate(90deg);transform:rotate(90deg)}.react-resizable-handle-se{bottom:0;right:0;cursor:se-resize}.react-resizable-handle-nw{top:0;left:0;cursor:nw-resize;-webkit-transform:rotate(180deg);transform:rotate(180deg)}.react-resizable-handle-ne{top:0;right:0;cursor:ne-resize;-webkit-transform:rotate(270deg);transform:rotate(270deg)}.react-resizable-handle-e,.react-resizable-handle-w{top:50%;margin-top:-10px;cursor:ew-resize}.react-resizable-handle-w{left:0;-webkit-transform:rotate(135deg);transform:rotate(135deg)}.react-resizable-handle-e{right:0;-webkit-transform:rotate(315deg);transform:rotate(315deg)}.react-resizable-handle-n,.react-resizable-handle-s{left:50%;margin-left:-10px;cursor:ns-resize}.react-resizable-handle-n{top:0;-webkit-transform:rotate(225deg);transform:rotate(225deg)}.react-resizable-handle-s{bottom:0;-webkit-transform:rotate(45deg);transform:rotate(45deg)}
/*# sourceMappingURL=main.8d5084fd.chunk.css.map */